---
title: Paramètres fondamentaux de Django
author: Steve Kossouho
tags: [settings,django]
---

# Paramètres fondamentaux de Django

Récapitulatif des paramètres les plus rencontrés sur les projets Django simples.

----

## Catégories

- Applications prises en charge
- Base de données
- Templates
- Traduction
- URLs
- Service de fichiers (Média, Statiques)

----

## Applications prises en charge par le projet

`INSTALLED_APPS` : Liste des applications utilisées par votre projet Django.

Le système interne de Django utilise cette information pour découvrir automatiquement certaines
informations pour le projet; templates, modèles, admin, fichiers statiques etc.

----

## Base de données

`DATABASES` : Permet de configurer une ou plusieurs bases de données à utiliser avec le projet Django.

La configuration la plus simple à mettre en place utilise une base de données SQLite3. Notez que pour une
utilisation en production, une base de données SQLite3 est fortement déconseillée (du moins pour une application
complexe autorisant la connexion de plusieurs clients simultanément).

----

## Templates (Gabarits)

`TEMPLATES` : Configurer les moteurs de gabarits utilisés par notre projet. Dans 99.9% des cas, la
configuration de base est suffisante, à quelques exceptions près.

----

```python {.number-lines}
TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]
```

Configuration des moteurs de gabarits

----

Parmi les clés présentes dans le paramètre `TEMPLATES`, se trouvent les clés suivantes :

- `APP_DIRS` : Automatiquement prendre en compte les répertoires `templates` des applications présentes dans `INSTALLED_APPS`.
- `context_processors` : fonctions qui ajoutent des informations accessibles pendant le rendu d'un template.
